@@ -10,6 +10,7 @@ enum {
 	ATA_OP_READ_LONG_ONCE		= 0x23,
 	ATA_OP_READ_PIO_EXT		= 0x24,
 	ATA_OP_READ_DMA_EXT		= 0x25,
+	ATA_OP_READ_LOG_EXT		= 0x2f,
 	ATA_OP_READ_FPDMA		= 0x60,	// NCQ
 	ATA_OP_WRITE_PIO		= 0x30,
 	ATA_OP_WRITE_LONG		= 0x32,
@@ -29,8 +30,10 @@ enum {
 	ATA_OP_PIDENTIFY		= 0xa1,
 	ATA_OP_READ_NATIVE_MAX		= 0xf8,
 	ATA_OP_READ_NATIVE_MAX_EXT	= 0x27,
+	ATA_OP_GET_NATIVE_MAX_EXT	= 0x78,
 	ATA_OP_SMART			= 0xb0,
 	ATA_OP_DCO			= 0xb1,
+	ATA_OP_SANITIZE			= 0xb4,
 	ATA_OP_ERASE_SECTORS		= 0xc0,
 	ATA_OP_READ_DMA			= 0xc8,
 	ATA_OP_WRITE_DMA		= 0xca,
